@@ -147,6 +147,12 @@ module Tmuxinator
       yaml["tmux_command"] || "tmux"
     end
 
+    def tmux_has_session?(name)
+      sessions = `#{tmux_command} ls`
+
+      !!sessions.match("^#{name}:")
+    end
+
     def socket
       if socket_path
         " -S #{socket_path}"
@@ -242,6 +248,10 @@ module Tmuxinator
       "#{tmux} new-session -d -s #{name} #{window}"
     end
 
+    def tmux_kill_session_command
+      "#{tmux} kill-session -t #{name}"
+    end
+
     private
 
     def tmux_config
