@@ -6,7 +6,7 @@ module Tmuxinator
 
     def initialize(window_yaml, index, project)
       @name = if !window_yaml.keys.first.nil?
-                window_yaml.keys.first.shellescape
+                window_yaml.keys.first.to_s.shellescape
               end
       @root = nil
       @panes = []
@@ -95,6 +95,10 @@ module Tmuxinator
       "#{project.tmux} new-window #{path} -t #{tmux_window_target} #{tmux_window_name_option}"
     end
 
+    def tmux_tiled_layout_command
+      "#{project.tmux} select-layout -t #{tmux_window_target} tiled"
+    end
+
     def tmux_layout_command
       "#{project.tmux} select-layout -t #{tmux_window_target} #{layout}"
     end
