@@ -8,6 +8,9 @@ describe Tmuxinator::Project do
   let(:project_with_number_as_name) do
     FactoryGirl.build(:project_with_number_as_name)
   end
+  let(:project_with_literals_as_window_name) do
+    FactoryGirl.build(:project_with_literals_as_window_name)
+  end
   let(:project_with_deprecations) do
     FactoryGirl.build(:project_with_deprecations)
   end
@@ -53,6 +56,28 @@ describe Tmuxinator::Project do
     end
   end
 
+  describe "#tmux_has_session?" do
+    before do
+      cmd = "#{project.tmux_command} ls"
+      resp = ""\
+        "foo: 1 window (created Sun May 25 10:12:00 1986) [50x50] (detached)\n"\
+        "bar: 1 window (created Sat Sept 01 00:00:00 1990) [50x50] (detached)"
+      call_tmux_ls = receive(:`).with(cmd).at_least(:once).and_return(resp)
+
+      expect(project).to call_tmux_ls
+    end
+
+    it "should return true only when `tmux ls` has the named session" do
+      expect(project.tmux_has_session?("foo")).to be true
+      expect(project.tmux_has_session?("bar")).to be true
+      expect(project.tmux_has_session?("quux")).to be false
+    end
+
+    it "should return false if a partial (prefix) match is found" do
+      expect(project.tmux_has_session?("foobar")).to be false
+    end
+  end
+
   describe "#windows" do
     context "without deprecations" do
       it "gets the list of windows" do
@@ -118,6 +143,15 @@ describe Tmuxinator::Project do
         expect(rendered.name.to_i).to_not equal 0
       end
     end
+
+    context "window as non-string literal" do
+      it "will gracefully handle a window name given as a non-string literal" do
+        rendered = project_with_literals_as_window_name
+        expect(rendered.windows.map(&:name)).to match_array(
+          %w(222 222333 111222333444555666777 222.3 4e5 4E5
+             true false nil // /sample/))
+      end
+    end
   end
 
   describe "#pre_window" do
@@ -448,6 +482,18 @@ describe Tmuxinator::Project do
     end
   end
 
+  describe "tmux_kill_session_command" do
+    let(:command) { "#{executable} kill-session -t #{session}" }
+    let(:executable) { project.tmux }
+    let(:session) { project.name }
+
+    context "when first window has a name" do
+      it "returns command to start a new detatched session" do
+        expect(project.tmux_kill_session_command).to eq command
+      end
+    end
+  end
+
   describe "::load" do
     let(:path) { File.expand_path("../../../fixtures/sample.yml", __FILE__) }
     let(:options) { {} }
